summaryrefslogtreecommitdiffstats
path: root/tdeio/tdefile
diff options
context:
space:
mode:
Diffstat (limited to 'tdeio/tdefile')
-rw-r--r--tdeio/tdefile/ChangeLog4
-rw-r--r--tdeio/tdefile/NOTES2
-rw-r--r--tdeio/tdefile/kacleditwidget.cpp10
-rw-r--r--tdeio/tdefile/kacleditwidget_p.h4
-rw-r--r--tdeio/tdefile/kcombiview.cpp2
-rw-r--r--tdeio/tdefile/kcombiview.h2
-rw-r--r--tdeio/tdefile/kcustommenueditor.cpp2
-rw-r--r--tdeio/tdefile/kcustommenueditor.h4
-rw-r--r--tdeio/tdefile/kdiroperator.cpp94
-rw-r--r--tdeio/tdefile/kdiroperator.h70
-rw-r--r--tdeio/tdefile/kdirselectdialog.cpp12
-rw-r--r--tdeio/tdefile/kdirselectdialog.h6
-rw-r--r--tdeio/tdefile/kencodingfiledialog.cpp6
-rw-r--r--tdeio/tdefile/knotifydialog.h2
-rw-r--r--tdeio/tdefile/knotifywidgetbase.ui2
-rw-r--r--tdeio/tdefile/kopenwith.cpp6
-rw-r--r--tdeio/tdefile/kopenwith_p.h4
-rw-r--r--tdeio/tdefile/kpropertiesdesktopbase.ui2
-rw-r--r--tdeio/tdefile/kpropertiesdialog.cpp4
-rw-r--r--tdeio/tdefile/kpropertiesmimetypebase.ui2
-rw-r--r--tdeio/tdefile/krecentdirs.cpp6
-rw-r--r--tdeio/tdefile/krecentdirs.h2
-rw-r--r--tdeio/tdefile/krecentdocument.cpp18
-rw-r--r--tdeio/tdefile/krecentdocument.h2
-rw-r--r--tdeio/tdefile/kurlbar.cpp6
-rw-r--r--tdeio/tdefile/kurlbar.h4
-rw-r--r--tdeio/tdefile/kurlrequester.cpp4
-rw-r--r--tdeio/tdefile/kurlrequester.h2
-rw-r--r--tdeio/tdefile/kurlrequesterdlg.cpp2
-rw-r--r--tdeio/tdefile/tdefilebookmarkhandler.cpp2
-rw-r--r--tdeio/tdefile/tdefilebookmarkhandler.h6
-rw-r--r--tdeio/tdefile/tdefiledetailview.cpp24
-rw-r--r--tdeio/tdefile/tdefiledetailview.h16
-rw-r--r--tdeio/tdefile/tdefiledialog.cpp42
-rw-r--r--tdeio/tdefile/tdefiledialog.h16
-rw-r--r--tdeio/tdefile/tdefileiconview.cpp12
-rw-r--r--tdeio/tdefile/tdefilepreview.cpp2
-rw-r--r--tdeio/tdefile/tdefilepreview.h4
-rw-r--r--tdeio/tdefile/tdefiletreeview.cpp10
-rw-r--r--tdeio/tdefile/tdefiletreeview.h2
-rw-r--r--tdeio/tdefile/tdefiletreeviewitem.cpp4
-rw-r--r--tdeio/tdefile/tdefiletreeviewitem.h2
-rw-r--r--tdeio/tdefile/tdefileview.cpp6
-rw-r--r--tdeio/tdefile/tdefileview.h4
-rw-r--r--tdeio/tdefile/tests/tdefiletreeviewtest.cpp2
-rw-r--r--tdeio/tdefile/tests/tdefiletreeviewtest.h2
46 files changed, 221 insertions, 221 deletions
diff --git a/tdeio/tdefile/ChangeLog b/tdeio/tdefile/ChangeLog
index 79ac59808..ccfb45ab5 100644
--- a/tdeio/tdefile/ChangeLog
+++ b/tdeio/tdefile/ChangeLog
@@ -62,7 +62,7 @@ Tue Feb 15 14:21:41 2000 Carsten Pfeiffer <pfeiffer@kde.org>
* kdiroperator.cpp (setSorting):
added setSorting() and sorting() to keep sorting when switching views
- a few cosmetic and KAction changes
+ a few cosmetic and TDEAction changes
Sun Feb 13 00:45:12 2000 Carsten Pfeiffer <pfeiffer@kde.org>
@@ -87,7 +87,7 @@ Fri Feb 11 12:17:59 2000 Carsten Pfeiffer <pfeiffer@kde.org>
Thu Feb 10 17:06:36 2000 Carsten Pfeiffer <pfeiffer@kde.org>
* kdiroperator.cpp (connectView):
- - Now that KToggleAction is fixed, I can commit the new stuff:
+ - Now that TDEToggleAction is fixed, I can commit the new stuff:
Offer Actions for all the common functionality, i.e. sorting, setting
the view, home(), cdUp(), back, forward, etc.
All actions are exposed through a QActionCollection
diff --git a/tdeio/tdefile/NOTES b/tdeio/tdefile/NOTES
index ad99065be..e2037e382 100644
--- a/tdeio/tdefile/NOTES
+++ b/tdeio/tdefile/NOTES
@@ -82,7 +82,7 @@ konqueror versions of the views.
This class inherits KParts::ReadOnlyPart, and provides a BrowserExtension.
It integrates KonqFileManagerWidget as its KParts widget, and provides
-KActions for it.
+TDEActions for it.
Important :
diff --git a/tdeio/tdefile/kacleditwidget.cpp b/tdeio/tdefile/kacleditwidget.cpp
index 94ee0d4c4..01eb8bcb8 100644
--- a/tdeio/tdefile/kacleditwidget.cpp
+++ b/tdeio/tdefile/kacleditwidget.cpp
@@ -143,7 +143,7 @@ KACLListViewItem::KACLListViewItem( TQListView* parent,
KACLListView::EntryType _type,
unsigned short _value, bool defaults,
const TQString& _qualifier )
- : KListViewItem( parent, parent->lastItem() ), // we want to append
+ : TDEListViewItem( parent, parent->lastItem() ), // we want to append
type( _type ), value( _value ), isDefault( defaults ),
qualifier( _qualifier ), isPartial( false )
{
@@ -204,7 +204,7 @@ void KACLListViewItem::paintCell( TQPainter* p, const TQColorGroup &cg,
mycg.setColor( TQColorGroup::Text, TQColor( 100, 100, 100 ) );
p->setFont( font );
}
- KListViewItem::paintCell( p, mycg, column, width, alignment );
+ TDEListViewItem::paintCell( p, mycg, column, width, alignment );
KACLListViewItem *below =0;
if ( itemBelow() )
@@ -556,7 +556,7 @@ void EditACLEntryDialog::slotSelectionChanged( int id )
KACLListView::KACLListView( TQWidget* parent, const char* name )
- : KListView( parent, name ),
+ : TDEListView( parent, name ),
m_hasMask( false ), m_allowDefaults( false )
{
// Add the columns
@@ -753,7 +753,7 @@ void KACLListView::contentsMousePressEvent( TQMouseEvent * e )
if ( !clickedItem ) return;
// if the click is on an as yet unselected item, select it first
if ( !clickedItem->isSelected() )
- KListView::contentsMousePressEvent( e );
+ TDEListView::contentsMousePressEvent( e );
if ( !currentItem() ) return;
int column = header()->sectionAt( e->x() );
@@ -770,7 +770,7 @@ void KACLListView::contentsMousePressEvent( TQMouseEvent * e )
perm = ACL_EXECUTE;
break;
default:
- return KListView::contentsMousePressEvent( e );
+ return TDEListView::contentsMousePressEvent( e );
}
KACLListViewItem* referenceItem = static_cast<KACLListViewItem*>( clickedItem );
unsigned short referenceHadItSet = referenceItem->value & perm;
diff --git a/tdeio/tdefile/kacleditwidget_p.h b/tdeio/tdefile/kacleditwidget_p.h
index dc7e4c811..9ea5e3203 100644
--- a/tdeio/tdefile/kacleditwidget_p.h
+++ b/tdeio/tdefile/kacleditwidget_p.h
@@ -47,7 +47,7 @@ class TQCheckBox;
/**
@author Sean Harmer
*/
-class KACLListView : public KListView
+class KACLListView : public TDEListView
{
Q_OBJECT
@@ -168,7 +168,7 @@ private:
};
-class KACLListViewItem : public KListViewItem
+class KACLListViewItem : public TDEListViewItem
{
public:
KACLListViewItem( TQListView* parent, KACLListView::EntryType type,
diff --git a/tdeio/tdefile/kcombiview.cpp b/tdeio/tdefile/kcombiview.cpp
index bc3d43384..ae408c8e2 100644
--- a/tdeio/tdefile/kcombiview.cpp
+++ b/tdeio/tdefile/kcombiview.cpp
@@ -319,7 +319,7 @@ void KCombiView::writeConfig( TDEConfig *config, const TQString& group )
right->writeConfig( config, group );
}
-KActionCollection * KCombiView::actionCollection() const
+TDEActionCollection * KCombiView::actionCollection() const
{
return focusView( right )->actionCollection();
}
diff --git a/tdeio/tdefile/kcombiview.h b/tdeio/tdefile/kcombiview.h
index 8da3da3fb..995b80ffc 100644
--- a/tdeio/tdefile/kcombiview.h
+++ b/tdeio/tdefile/kcombiview.h
@@ -98,7 +98,7 @@ public:
void ensureItemVisible( const KFileItem * );
- virtual KActionCollection * actionCollection() const;
+ virtual TDEActionCollection * actionCollection() const;
virtual void setAcceptDrops(bool b);
diff --git a/tdeio/tdefile/kcustommenueditor.cpp b/tdeio/tdefile/kcustommenueditor.cpp
index 48c911e30..244e22e84 100644
--- a/tdeio/tdefile/kcustommenueditor.cpp
+++ b/tdeio/tdefile/kcustommenueditor.cpp
@@ -90,7 +90,7 @@ KCustomMenuEditor::KCustomMenuEditor(TQWidget *parent)
{
d = new KCustomMenuEditorPrivate;
TQHBox *page = makeHBoxMainWidget();
- m_listView = new KListView(page);
+ m_listView = new TDEListView(page);
m_listView->addColumn(i18n("Menu"));
m_listView->setFullWidth(true);
m_listView->setSorting(-1);
diff --git a/tdeio/tdefile/kcustommenueditor.h b/tdeio/tdefile/kcustommenueditor.h
index 108e9c477..cb43c606f 100644
--- a/tdeio/tdefile/kcustommenueditor.h
+++ b/tdeio/tdefile/kcustommenueditor.h
@@ -21,7 +21,7 @@
#include <kdialogbase.h>
-class KListView;
+class TDEListView;
class TDEConfigBase;
/*
@@ -58,7 +58,7 @@ public slots:
protected:
class Item;
- KListView *m_listView;
+ TDEListView *m_listView;
class KCustomMenuEditorPrivate;
KCustomMenuEditorPrivate *d;
diff --git a/tdeio/tdefile/kdiroperator.cpp b/tdeio/tdefile/kdiroperator.cpp
index ea3183f78..dcb457662 100644
--- a/tdeio/tdefile/kdiroperator.cpp
+++ b/tdeio/tdefile/kdiroperator.cpp
@@ -87,7 +87,7 @@ public:
TQString lastURL; // used for highlighting a directory on cdUp
bool onlyDoubleClickSelectsFiles;
TQTimer *progressDelayTimer;
- KActionSeparator *viewActionSeparator;
+ TDEActionSeparator *viewActionSeparator;
int dropOptions;
TDEConfig *config;
@@ -192,10 +192,10 @@ void KDirOperator::insertViewDependentActions()
{
if (viewActionCollection)
{
- disconnect( viewActionCollection, TQT_SIGNAL( inserted( KAction * )),
- this, TQT_SLOT( slotViewActionAdded( KAction * )));
- disconnect( viewActionCollection, TQT_SIGNAL( removed( KAction * )),
- this, TQT_SLOT( slotViewActionRemoved( KAction * )));
+ disconnect( viewActionCollection, TQT_SIGNAL( inserted( TDEAction * )),
+ this, TQT_SLOT( slotViewActionAdded( TDEAction * )));
+ disconnect( viewActionCollection, TQT_SIGNAL( removed( TDEAction * )),
+ this, TQT_SLOT( slotViewActionRemoved( TDEAction * )));
}
viewActionMenu->popupMenu()->clear();
@@ -223,24 +223,24 @@ void KDirOperator::insertViewDependentActions()
TQStringList groups = viewActionCollection->groups();
groups.prepend( TQString::null ); // actions without group
TQStringList::ConstIterator git = groups.begin();
- KActionPtrList list;
- KAction *sep = actionCollection()->action("separator");
+ TDEActionPtrList list;
+ TDEAction *sep = actionCollection()->action("separator");
for ( ; git != groups.end(); ++git )
{
if ( git != groups.begin() )
viewActionMenu->insert( sep );
list = viewActionCollection->actions( *git );
- KActionPtrList::ConstIterator it = list.begin();
+ TDEActionPtrList::ConstIterator it = list.begin();
for ( ; it != list.end(); ++it )
viewActionMenu->insert( *it );
}
}
- connect( viewActionCollection, TQT_SIGNAL( inserted( KAction * )),
- TQT_SLOT( slotViewActionAdded( KAction * )));
- connect( viewActionCollection, TQT_SIGNAL( removed( KAction * )),
- TQT_SLOT( slotViewActionRemoved( KAction * )));
+ connect( viewActionCollection, TQT_SIGNAL( inserted( TDEAction * )),
+ TQT_SLOT( slotViewActionAdded( TDEAction * )));
+ connect( viewActionCollection, TQT_SIGNAL( removed( TDEAction * )),
+ TQT_SLOT( slotViewActionRemoved( TDEAction * )));
}
}
@@ -271,7 +271,7 @@ void KDirOperator::setPreviewWidget(const TQWidget *w)
delete myPreview;
myPreview = w;
- KToggleAction *preview = static_cast<KToggleAction*>(myActionCollection->action("preview"));
+ TDEToggleAction *preview = static_cast<TDEToggleAction*>(myActionCollection->action("preview"));
preview->setEnabled( w != 0L );
preview->setChecked( w != 0L );
setView( static_cast<KFile::FileView>(m_viewKind) );
@@ -326,7 +326,7 @@ void KDirOperator::slotDefaultPreview()
m_viewKind = m_viewKind | KFile::PreviewContents;
if ( !myPreview ) {
myPreview = new KFileMetaPreview( this );
- (static_cast<KToggleAction*>( myActionCollection->action("preview") ))->setChecked(true);
+ (static_cast<TDEToggleAction*>( myActionCollection->action("preview") ))->setChecked(true);
}
setView( static_cast<KFile::FileView>(m_viewKind) );
@@ -555,12 +555,12 @@ TDEIO::CopyJob * KDirOperator::trash( const KFileItemList& items,
return 0L;
}
-void KDirOperator::trashSelected(KAction::ActivationReason reason, TQt::ButtonState state)
+void KDirOperator::trashSelected(TDEAction::ActivationReason reason, TQt::ButtonState state)
{
if ( !m_fileView )
return;
- if ( reason == KAction::PopupMenuActivation && ( state & ShiftButton ) ) {
+ if ( reason == TDEAction::PopupMenuActivation && ( state & ShiftButton ) ) {
deleteSelected();
return;
}
@@ -809,7 +809,7 @@ void KDirOperator::setMimeFilter( const TQStringList& mimetypes )
bool KDirOperator::checkPreviewSupport()
{
- KToggleAction *previewAction = static_cast<KToggleAction*>( myActionCollection->action( "preview" ));
+ TDEToggleAction *previewAction = static_cast<TDEToggleAction*>( myActionCollection->action( "preview" ));
bool hasPreviewSupport = false;
TDEConfig *kc = TDEGlobal::config();
@@ -1253,9 +1253,9 @@ void KDirOperator::slotCompletionMatch(const TQString& match)
void KDirOperator::setupActions()
{
- myActionCollection = new KActionCollection( topLevelWidget(), TQT_TQOBJECT(this), "KDirOperator::myActionCollection" );
+ myActionCollection = new TDEActionCollection( topLevelWidget(), TQT_TQOBJECT(this), "KDirOperator::myActionCollection" );
- actionMenu = new KActionMenu( i18n("Menu"), myActionCollection, "popupMenu" );
+ actionMenu = new TDEActionMenu( i18n("Menu"), myActionCollection, "popupMenu" );
upAction = KStdAction::up( TQT_TQOBJECT(this), TQT_SLOT( cdUp() ), myActionCollection, "up" );
upAction->setText( i18n("Parent Folder") );
backAction = KStdAction::back( TQT_TQOBJECT(this), TQT_SLOT( back() ), myActionCollection, "back" );
@@ -1263,33 +1263,33 @@ void KDirOperator::setupActions()
homeAction = KStdAction::home( TQT_TQOBJECT(this), TQT_SLOT( home() ), myActionCollection, "home" );
homeAction->setText(i18n("Home Folder"));
reloadAction = KStdAction::redisplay( TQT_TQOBJECT(this), TQT_SLOT(rereadDir()), myActionCollection, "reload" );
- actionSeparator = new KActionSeparator( myActionCollection, "separator" );
- d->viewActionSeparator = new KActionSeparator( myActionCollection,
+ actionSeparator = new TDEActionSeparator( myActionCollection, "separator" );
+ d->viewActionSeparator = new TDEActionSeparator( myActionCollection,
"viewActionSeparator" );
- mkdirAction = new KAction( i18n("New Folder..."), 0,
+ mkdirAction = new TDEAction( i18n("New Folder..."), 0,
TQT_TQOBJECT(this), TQT_SLOT( mkdir() ), myActionCollection, "mkdir" );
- KAction* trash = new KAction( i18n( "Move to Trash" ), "edittrash", Key_Delete, myActionCollection, "trash" );
- connect( trash, TQT_SIGNAL( activated( KAction::ActivationReason, TQt::ButtonState ) ),
- this, TQT_SLOT( trashSelected( KAction::ActivationReason, TQt::ButtonState ) ) );
- new KAction( i18n( "Delete" ), "editdelete", SHIFT+Key_Delete, TQT_TQOBJECT(this),
+ TDEAction* trash = new TDEAction( i18n( "Move to Trash" ), "edittrash", Key_Delete, myActionCollection, "trash" );
+ connect( trash, TQT_SIGNAL( activated( TDEAction::ActivationReason, TQt::ButtonState ) ),
+ this, TQT_SLOT( trashSelected( TDEAction::ActivationReason, TQt::ButtonState ) ) );
+ new TDEAction( i18n( "Delete" ), "editdelete", SHIFT+Key_Delete, TQT_TQOBJECT(this),
TQT_SLOT( deleteSelected() ), myActionCollection, "delete" );
mkdirAction->setIcon( TQString::fromLatin1("folder_new") );
reloadAction->setText( i18n("Reload") );
- reloadAction->setShortcut( KStdAccel::shortcut( KStdAccel::Reload ));
+ reloadAction->setShortcut( TDEStdAccel::shortcut( TDEStdAccel::Reload ));
// the sort menu actions
- sortActionMenu = new KActionMenu( i18n("Sorting"), myActionCollection, "sorting menu");
- byNameAction = new KRadioAction( i18n("By Name"), 0,
+ sortActionMenu = new TDEActionMenu( i18n("Sorting"), myActionCollection, "sorting menu");
+ byNameAction = new TDERadioAction( i18n("By Name"), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotSortByName() ),
myActionCollection, "by name" );
- byDateAction = new KRadioAction( i18n("By Date"), 0,
+ byDateAction = new TDERadioAction( i18n("By Date"), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotSortByDate() ),
myActionCollection, "by date" );
- bySizeAction = new KRadioAction( i18n("By Size"), 0,
+ bySizeAction = new TDERadioAction( i18n("By Size"), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotSortBySize() ),
myActionCollection, "by size" );
- reverseAction = new KToggleAction( i18n("Reverse"), 0,
+ reverseAction = new TDEToggleAction( i18n("Reverse"), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotSortReversed() ),
myActionCollection, "reversed" );
@@ -1299,9 +1299,9 @@ void KDirOperator::setupActions()
bySizeAction->setExclusiveGroup( sortGroup );
- dirsFirstAction = new KToggleAction( i18n("Folders First"), 0,
+ dirsFirstAction = new TDEToggleAction( i18n("Folders First"), 0,
myActionCollection, "dirs first");
- caseInsensitiveAction = new KToggleAction(i18n("Case Insensitive"), 0,
+ caseInsensitiveAction = new TDEToggleAction(i18n("Case Insensitive"), 0,
myActionCollection, "case insensitive" );
connect( dirsFirstAction, TQT_SIGNAL( toggled( bool ) ),
@@ -1312,24 +1312,24 @@ void KDirOperator::setupActions()
// the view menu actions
- viewActionMenu = new KActionMenu( i18n("&View"), myActionCollection, "view menu" );
+ viewActionMenu = new TDEActionMenu( i18n("&View"), myActionCollection, "view menu" );
connect( viewActionMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ),
TQT_SLOT( insertViewDependentActions() ));
- shortAction = new KRadioAction( i18n("Short View"), "view_multicolumn",
- KShortcut(), myActionCollection, "short view" );
- detailedAction = new KRadioAction( i18n("Detailed View"), "view_detailed",
- KShortcut(), myActionCollection, "detailed view" );
+ shortAction = new TDERadioAction( i18n("Short View"), "view_multicolumn",
+ TDEShortcut(), myActionCollection, "short view" );
+ detailedAction = new TDERadioAction( i18n("Detailed View"), "view_detailed",
+ TDEShortcut(), myActionCollection, "detailed view" );
- showHiddenAction = new KToggleAction( i18n("Show Hidden Files"), KShortcut(),
+ showHiddenAction = new TDEToggleAction( i18n("Show Hidden Files"), TDEShortcut(),
myActionCollection, "show hidden" );
// showHiddenAction->setCheckedState( i18n("Hide Hidden Files") );
- separateDirsAction = new KToggleAction( i18n("Separate Folders"), KShortcut(),
+ separateDirsAction = new TDEToggleAction( i18n("Separate Folders"), TDEShortcut(),
TQT_TQOBJECT(this),
TQT_SLOT(slotSeparateDirs()),
myActionCollection, "separate dirs" );
- KToggleAction *previewAction = new KToggleAction(i18n("Show Preview"),
- "thumbnail", KShortcut(),
+ TDEToggleAction *previewAction = new TDEToggleAction(i18n("Show Preview"),
+ "thumbnail", TDEShortcut(),
myActionCollection,
"preview" );
previewAction->setCheckedState(i18n("Hide Preview"));
@@ -1348,7 +1348,7 @@ void KDirOperator::setupActions()
connect( showHiddenAction, TQT_SIGNAL( toggled( bool ) ),
TQT_SLOT( slotToggleHidden( bool ) ));
- new KAction( i18n("Properties"), KShortcut(ALT+Key_Return), TQT_TQOBJECT(this),
+ new TDEAction( i18n("Properties"), TDEShortcut(ALT+Key_Return), TQT_TQOBJECT(this),
TQT_SLOT(slotProperties()), myActionCollection, "properties" );
}
@@ -1533,7 +1533,7 @@ void KDirOperator::writeConfig( TDEConfig *kc, const TQString& group )
kc->writeEntry( TQString::fromLatin1("Separate Directories"),
separateDirsAction->isChecked() );
- KToggleAction *previewAction = static_cast<KToggleAction*>(myActionCollection->action("preview"));
+ TDEToggleAction *previewAction = static_cast<TDEToggleAction*>(myActionCollection->action("preview"));
if ( previewAction->isEnabled() ) {
bool hasPreview = previewAction->isChecked();
kc->writeEntry( TQString::fromLatin1("Show Preview"), hasPreview );
@@ -1633,7 +1633,7 @@ void KDirOperator::clearHistory()
forwardAction->setEnabled( false );
}
-void KDirOperator::slotViewActionAdded( KAction *action )
+void KDirOperator::slotViewActionAdded( TDEAction *action )
{
if ( viewActionMenu->popupMenu()->count() == 5 ) // need to add a separator
viewActionMenu->insert( d->viewActionSeparator );
@@ -1641,7 +1641,7 @@ void KDirOperator::slotViewActionAdded( KAction *action )
viewActionMenu->insert( action );
}
-void KDirOperator::slotViewActionRemoved( KAction *action )
+void KDirOperator::slotViewActionRemoved( TDEAction *action )
{
viewActionMenu->remove( action );
diff --git a/tdeio/tdefile/kdirselectdialog.cpp b/tdeio/tdefile/kdirselectdialog.cpp
index 6a13920fd..a540c57ef 100644
--- a/tdeio/tdefile/kdirselectdialog.cpp
+++ b/tdeio/tdefile/kdirselectdialog.cpp
@@ -122,10 +122,10 @@ KDirSelectDialog::KDirSelectDialog(const TQString &startDir, bool localOnly,
TQT_SLOT( slotComboTextChanged( const TQString& ) ));
m_contextMenu = new TQPopupMenu( this );
- KAction* newFolder = new KAction( i18n("New Folder..."), "folder_new", 0, TQT_TQOBJECT(this), TQT_SLOT( slotMkdir() ), TQT_TQOBJECT(this));
+ TDEAction* newFolder = new TDEAction( i18n("New Folder..."), "folder_new", 0, TQT_TQOBJECT(this), TQT_SLOT( slotMkdir() ), TQT_TQOBJECT(this));
newFolder->plug(m_contextMenu);
m_contextMenu->insertSeparator();
- m_showHiddenFolders = new KToggleAction ( i18n( "Show Hidden Folders" ), 0, TQT_TQOBJECT(this),
+ m_showHiddenFolders = new TDEToggleAction ( i18n( "Show Hidden Folders" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotShowHiddenFoldersToggled() ), TQT_TQOBJECT(this));
m_showHiddenFolders->plug(m_contextMenu);
@@ -153,8 +153,8 @@ KDirSelectDialog::KDirSelectDialog(const TQString &startDir, bool localOnly,
connect( m_treeView, TQT_SIGNAL( currentChanged( TQListViewItem * )),
TQT_SLOT( slotCurrentChanged() ));
- connect( m_treeView, TQT_SIGNAL( contextMenu( KListView *, TQListViewItem *, const TQPoint & )),
- TQT_SLOT( slotContextMenu( KListView *, TQListViewItem *, const TQPoint & )));
+ connect( m_treeView, TQT_SIGNAL( contextMenu( TDEListView *, TQListViewItem *, const TQPoint & )),
+ TQT_SLOT( slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint & )));
connect( d->urlCombo, TQT_SIGNAL( activated( const TQString& )),
TQT_SLOT( slotURLActivated( const TQString& )));
@@ -307,7 +307,7 @@ void KDirSelectDialog::accept()
if ( !item->isDir() )
dir = dir.upURL();
- KRecentDirs::add(d->recentDirClass, dir.url());
+ TDERecentDirs::add(d->recentDirClass, dir.url());
}
d->urlCombo->addToHistory( item->url().prettyURL() );
@@ -395,7 +395,7 @@ void KDirSelectDialog::slotComboTextChanged( const TQString& text )
}
}
-void KDirSelectDialog::slotContextMenu( KListView *, TQListViewItem *, const TQPoint& pos )
+void KDirSelectDialog::slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint& pos )
{
m_contextMenu->popup( pos );
}
diff --git a/tdeio/tdefile/kdirselectdialog.h b/tdeio/tdefile/kdirselectdialog.h
index 746064c68..400bd3232 100644
--- a/tdeio/tdefile/kdirselectdialog.h
+++ b/tdeio/tdefile/kdirselectdialog.h
@@ -29,7 +29,7 @@ class TDEConfig;
class KFileTreeBranch;
class KFileTreeView;
class KFileTreeViewItem;
-class KToggleAction;
+class TDEToggleAction;
/**
* A pretty dialog for a KDirSelect control for selecting directories.
@@ -106,7 +106,7 @@ private slots:
void slotURLActivated( const TQString& );
void slotNextDirToList( KFileTreeViewItem *dirItem );
void slotComboTextChanged( const TQString& text );
- void slotContextMenu( KListView *, TQListViewItem *, const TQPoint & );
+ void slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint & );
void slotShowHiddenFoldersToggled();
void slotMkdir();
@@ -118,7 +118,7 @@ private:
KFileTreeView *m_treeView;
TQPopupMenu *m_contextMenu;
- KToggleAction *m_showHiddenFolders;
+ TDEToggleAction *m_showHiddenFolders;
bool m_localOnly;
protected:
diff --git a/tdeio/tdefile/kencodingfiledialog.cpp b/tdeio/tdefile/kencodingfiledialog.cpp
index b8c90f6ff..569217bee 100644
--- a/tdeio/tdefile/kencodingfiledialog.cpp
+++ b/tdeio/tdefile/kencodingfiledialog.cpp
@@ -44,7 +44,7 @@ KEncodingFileDialog::KEncodingFileDialog(const TQString& startDir, const TQStrin
setOperationMode( type );
- KToolBar *tb = toolBar();
+ TDEToolBar *tb = toolBar();
tb->insertSeparator();
int index = tb->insertCombo(TQStringList(), -1 /*id*/, false /*writable*/, 0 /*signal*/, 0 /*receiver*/, 0 /*slot*/ );
d->encoding = tb->getCombo( tb->idAt( index ) );
@@ -180,7 +180,7 @@ KEncodingFileDialog::Result KEncodingFileDialog::getSaveFileNameAndEncoding(cons
TQString filename = dlg.selectedFile();
if (!filename.isEmpty())
- KRecentDocument::add(filename);
+ TDERecentDocument::add(filename);
Result res;
res.fileNames<<filename;
@@ -204,7 +204,7 @@ KEncodingFileDialog::Result KEncodingFileDialog::getSaveURLAndEncoding(const TQ
KURL url = dlg.selectedURL();
if (url.isValid())
- KRecentDocument::add( url );
+ TDERecentDocument::add( url );
Result res;
res.URLs<<url;
diff --git a/tdeio/tdefile/knotifydialog.h b/tdeio/tdefile/knotifydialog.h
index 9bb3210ea..ede51d663 100644
--- a/tdeio/tdefile/knotifydialog.h
+++ b/tdeio/tdefile/knotifydialog.h
@@ -195,7 +195,7 @@ namespace KNotify
bool handleAllApps = false );
~KNotifyWidget();
- KListView * eventsView() {
+ TDEListView * eventsView() {
return m_listview;
}
diff --git a/tdeio/tdefile/knotifywidgetbase.ui b/tdeio/tdefile/knotifywidgetbase.ui
index d3c3103ff..023da77d8 100644
--- a/tdeio/tdefile/knotifywidgetbase.ui
+++ b/tdeio/tdefile/knotifywidgetbase.ui
@@ -19,7 +19,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string></string>
diff --git a/tdeio/tdefile/kopenwith.cpp b/tdeio/tdefile/kopenwith.cpp
index 691487730..8582e31f0 100644
--- a/tdeio/tdefile/kopenwith.cpp
+++ b/tdeio/tdefile/kopenwith.cpp
@@ -69,7 +69,7 @@
// ----------------------------------------------------------------------
-KAppTreeListItem::KAppTreeListItem( KListView* parent, const TQString & name,
+KAppTreeListItem::KAppTreeListItem( TDEListView* parent, const TQString & name,
const TQPixmap& pixmap, bool parse, bool dir, const TQString &p, const TQString &c )
: TQListViewItem( parent, name )
{
@@ -145,7 +145,7 @@ bool KAppTreeListItem::isDirectory()
// ----------------------------------------------------------------------
TDEApplicationTree::TDEApplicationTree( TQWidget *parent )
- : KListView( parent ), currentitem(0)
+ : TDEListView( parent ), currentitem(0)
{
addColumn( i18n("Known Applications") );
setRootIsDecorated( true );
@@ -281,7 +281,7 @@ void TDEApplicationTree::resizeEvent( TQResizeEvent * e)
{
setColumnWidth(0, width()-TQApplication::style().pixelMetric(TQStyle::PM_ScrollBarExtent)
-2*TQApplication::style().pixelMetric(TQStyle::PM_DefaultFrameWidth));
- KListView::resizeEvent(e);
+ TDEListView::resizeEvent(e);
}
// Prune empty directories from the tree
diff --git a/tdeio/tdefile/kopenwith_p.h b/tdeio/tdefile/kopenwith_p.h
index 8231da27d..ca9317fb6 100644
--- a/tdeio/tdefile/kopenwith_p.h
+++ b/tdeio/tdefile/kopenwith_p.h
@@ -51,7 +51,7 @@ protected:
void init(const TQPixmap& pixmap, bool parse, bool dir, const TQString &_path, const TQString &exec);
public:
- KAppTreeListItem( KListView* parent, const TQString & name, const TQPixmap& pixmap,
+ KAppTreeListItem( TDEListView* parent, const TQString & name, const TQPixmap& pixmap,
bool parse, bool dir, const TQString &p, const TQString &c );
KAppTreeListItem( TQListViewItem* parent, const TQString & name, const TQPixmap& pixmap,
bool parse, bool dir, const TQString &p, const TQString &c );
@@ -69,7 +69,7 @@ protected:
/**
* @internal
*/
-class TDEApplicationTree : public KListView
+class TDEApplicationTree : public TDEListView
{
Q_OBJECT
public:
diff --git a/tdeio/tdefile/kpropertiesdesktopbase.ui b/tdeio/tdefile/kpropertiesdesktopbase.ui
index a0894dc70..9c08eef93 100644
--- a/tdeio/tdefile/kpropertiesdesktopbase.ui
+++ b/tdeio/tdefile/kpropertiesdesktopbase.ui
@@ -52,7 +52,7 @@
&lt;p&gt;If you want to associate this application with one or more mimetypes that are not in this list, click on the button &lt;b&gt;Add&lt;/b&gt; below. If there are one or more filetypes that this application cannot handle, you may want to remove them from the list clicking on the button &lt;b&gt;Remove&lt;/b&gt; below.&lt;/p&gt;&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="KListView" row="7" column="0" rowspan="1" colspan="7">
+ <widget class="TDEListView" row="7" column="0" rowspan="1" colspan="7">
<column>
<property name="text">
<string>Mimetype</string>
diff --git a/tdeio/tdefile/kpropertiesdialog.cpp b/tdeio/tdefile/kpropertiesdialog.cpp
index 0e9f125a6..fdbef4fea 100644
--- a/tdeio/tdefile/kpropertiesdialog.cpp
+++ b/tdeio/tdefile/kpropertiesdialog.cpp
@@ -498,7 +498,7 @@ void KPropertiesDialog::insertPages()
insertPlugin (p);
}
- if ( kapp->authorizeKAction("sharefile") &&
+ if ( kapp->authorizeTDEAction("sharefile") &&
KFileSharePropsPlugin::supports( m_items ) )
{
KPropsDlgPlugin *p = new KFileSharePropsPlugin( this );
@@ -953,7 +953,7 @@ KFilePropsPlugin::KFilePropsPlugin( KPropertiesDialog *_props )
connect( button, TQT_SIGNAL( clicked() ), TQT_SLOT( slotEditFileType() ));
- if (!kapp->authorizeKAction("editfiletype"))
+ if (!kapp->authorizeTDEAction("editfiletype"))
button->hide();
#endif
diff --git a/tdeio/tdefile/kpropertiesmimetypebase.ui b/tdeio/tdefile/kpropertiesmimetypebase.ui
index df7c796da..257eaa57c 100644
--- a/tdeio/tdefile/kpropertiesmimetypebase.ui
+++ b/tdeio/tdefile/kpropertiesmimetypebase.ui
@@ -30,7 +30,7 @@
<cstring>listView</cstring>
</property>
</widget>
- <widget class="KListView">
+ <widget class="TDEListView">
<column>
<property name="text">
<string>Mimetype</string>
diff --git a/tdeio/tdefile/krecentdirs.cpp b/tdeio/tdefile/krecentdirs.cpp
index 6f4a01f3b..0d8d008bd 100644
--- a/tdeio/tdefile/krecentdirs.cpp
+++ b/tdeio/tdefile/krecentdirs.cpp
@@ -69,7 +69,7 @@ static TDEConfig *recentdirs_readList(TQString &key, TQStringList &result, bool
return config;
}
-TQStringList KRecentDirs::list(const TQString &fileClass)
+TQStringList TDERecentDirs::list(const TQString &fileClass)
{
TQString key = fileClass;
TQStringList result;
@@ -77,13 +77,13 @@ TQStringList KRecentDirs::list(const TQString &fileClass)
return result;
}
-TQString KRecentDirs::dir(const TQString &fileClass)
+TQString TDERecentDirs::dir(const TQString &fileClass)
{
TQStringList result = list(fileClass);
return result[0];
}
-void KRecentDirs::add(const TQString &fileClass, const TQString &directory)
+void TDERecentDirs::add(const TQString &fileClass, const TQString &directory)
{
TQString key = fileClass;
TQStringList result;
diff --git a/tdeio/tdefile/krecentdirs.h b/tdeio/tdefile/krecentdirs.h
index 774655e51..cc9be16b4 100644
--- a/tdeio/tdefile/krecentdirs.h
+++ b/tdeio/tdefile/krecentdirs.h
@@ -47,7 +47,7 @@
* a single ':' the file-class is specific to the current application.
* If the file-class starts with '::' it is global to all applications.
*/
-class TDEIO_EXPORT KRecentDirs
+class TDEIO_EXPORT TDERecentDirs
{
public:
/**
diff --git a/tdeio/tdefile/krecentdocument.cpp b/tdeio/tdefile/krecentdocument.cpp
index 1ec4a98c8..85af01c46 100644
--- a/tdeio/tdefile/krecentdocument.cpp
+++ b/tdeio/tdefile/krecentdocument.cpp
@@ -42,13 +42,13 @@
#include <sys/types.h>
#include <utime.h>
-TQString KRecentDocument::recentDocumentDirectory()
+TQString TDERecentDocument::recentDocumentDirectory()
{
// need to change this path, not sure where
return locateLocal("data", TQString::fromLatin1("RecentDocuments/"));
}
-TQStringList KRecentDocument::recentDocuments()
+TQStringList TDERecentDocument::recentDocuments()
{
TQDir d(recentDocumentDirectory(), "*.desktop", TQDir::Time,
TQDir::Files | TQDir::Readable | TQDir::Hidden);
@@ -72,12 +72,12 @@ TQStringList KRecentDocument::recentDocuments()
return fullList;
}
-void KRecentDocument::add(const KURL& url)
+void TDERecentDocument::add(const KURL& url)
{
- KRecentDocument::add(url, tqApp->argv()[0]); // ### argv[0] might not match the service filename!
+ TDERecentDocument::add(url, tqApp->argv()[0]); // ### argv[0] might not match the service filename!
}
-void KRecentDocument::add(const KURL& url, const TQString& desktopEntryName)
+void TDERecentDocument::add(const KURL& url, const TQString& desktopEntryName)
{
if ( url.isLocalFile() && !TDEGlobal::dirs()->relativeLocation("tmp", url.path()).startsWith("/"))
return;
@@ -85,7 +85,7 @@ void KRecentDocument::add(const KURL& url, const TQString& desktopEntryName)
TQString openStr = url.url();
openStr.replace( TQRegExp("\\$"), "$$" ); // Desktop files with type "Link" are $-variable expanded
- kdDebug(250) << "KRecentDocument::add for " << openStr << endl;
+ kdDebug(250) << "TDERecentDocument::add for " << openStr << endl;
TDEConfig *config = TDEGlobal::config();
TQString oldGrp = config->group();
config->setGroup(TQString::fromLatin1("RecentDocuments"));
@@ -148,7 +148,7 @@ void KRecentDocument::add(const KURL& url, const TQString& desktopEntryName)
conf.writeEntry( TQString::fromLatin1("Icon"), KMimeType::iconForURL( url ) );
}
-void KRecentDocument::add(const TQString &openStr, bool isUrl)
+void TDERecentDocument::add(const TQString &openStr, bool isUrl)
{
if( isUrl ) {
add( KURL( openStr ) );
@@ -159,7 +159,7 @@ void KRecentDocument::add(const TQString &openStr, bool isUrl)
}
}
-void KRecentDocument::clear()
+void TDERecentDocument::clear()
{
TQStringList list = recentDocuments();
TQDir dir;
@@ -167,7 +167,7 @@ void KRecentDocument::clear()
dir.remove(*it);
}
-int KRecentDocument::maximumItems()
+int TDERecentDocument::maximumItems()
{
TDEConfig *config = TDEGlobal::config();
TDEConfigGroupSaver sa(config, TQString::fromLatin1("RecentDocuments"));
diff --git a/tdeio/tdefile/krecentdocument.h b/tdeio/tdefile/krecentdocument.h
index 968559968..b788c0dc2 100644
--- a/tdeio/tdefile/krecentdocument.h
+++ b/tdeio/tdefile/krecentdocument.h
@@ -47,7 +47,7 @@
*
* @author Daniel M. Duley <mosfet@kde.org>
*/
-class TDEIO_EXPORT KRecentDocument
+class TDEIO_EXPORT TDERecentDocument
{
public:
diff --git a/tdeio/tdefile/kurlbar.cpp b/tdeio/tdefile/kurlbar.cpp
index e142845e1..2642926a1 100644
--- a/tdeio/tdefile/kurlbar.cpp
+++ b/tdeio/tdefile/kurlbar.cpp
@@ -406,7 +406,7 @@ void KURLBar::setListBox( KURLBarListBox *view )
m_listBox->resize( width(), height() );
}
- m_listBox->setSelectionMode( KListBox::Single );
+ m_listBox->setSelectionMode( TDEListBox::Single );
paletteChange( palette() );
m_listBox->setFocusPolicy( TQ_TabFocus );
@@ -829,7 +829,7 @@ bool KURLBar::editItem( KURLBarItem *item )
KURLBarListBox::KURLBarListBox( TQWidget *parent, const char *name )
- : KListBox( parent, name )
+ : TDEListBox( parent, name )
{
m_toolTip = new KURLBarToolTip( this );
setAcceptDrops( true );
@@ -1043,7 +1043,7 @@ void KURLBar::virtual_hook( int, void* )
{ /*BASE::virtual_hook( id, data );*/ }
void KURLBarListBox::virtual_hook( int id, void* data )
-{ KListBox::virtual_hook( id, data ); }
+{ TDEListBox::virtual_hook( id, data ); }
#include "kurlbar.moc"
diff --git a/tdeio/tdefile/kurlrequester.cpp b/tdeio/tdefile/kurlrequester.cpp
index cca8c0529..88b34ea6b 100644
--- a/tdeio/tdefile/kurlrequester.cpp
+++ b/tdeio/tdefile/kurlrequester.cpp
@@ -226,8 +226,8 @@ void KURLRequester::init()
myCompletion = new KURLCompletion();
d->setCompletionObject( myCompletion );
- KAccel *accel = new KAccel( this );
- accel->insert( KStdAccel::Open, TQT_TQOBJECT(this), TQT_SLOT( slotOpenDialog() ));
+ TDEAccel *accel = new TDEAccel( this );
+ accel->insert( TDEStdAccel::Open, TQT_TQOBJECT(this), TQT_SLOT( slotOpenDialog() ));
accel->readSettings();
}
diff --git a/tdeio/tdefile/kurlrequester.h b/tdeio/tdefile/kurlrequester.h
index 55bc0fd83..5655efa5b 100644
--- a/tdeio/tdefile/kurlrequester.h
+++ b/tdeio/tdefile/kurlrequester.h
@@ -269,7 +269,7 @@ private:
protected slots:
/**
* Called when the button is pressed to open the filedialog.
- * Also called when KStdAccel::Open (default is Ctrl-O) is pressed.
+ * Also called when TDEStdAccel::Open (default is Ctrl-O) is pressed.
*/
void slotOpenDialog();
diff --git a/tdeio/tdefile/kurlrequesterdlg.cpp b/tdeio/tdefile/kurlrequesterdlg.cpp
index 7524ea149..2459f984f 100644
--- a/tdeio/tdefile/kurlrequesterdlg.cpp
+++ b/tdeio/tdefile/kurlrequesterdlg.cpp
@@ -115,7 +115,7 @@ KURL KURLRequesterDlg::getURL(const TQString& dir, TQWidget *parent,
const KURL& url = dlg.selectedURL();
if (url.isValid())
- KRecentDocument::add(url);
+ TDERecentDocument::add(url);
return url;
}
diff --git a/tdeio/tdefile/tdefilebookmarkhandler.cpp b/tdeio/tdefile/tdefilebookmarkhandler.cpp
index ea97b8661..ef1f2a37b 100644
--- a/tdeio/tdefile/tdefilebookmarkhandler.cpp
+++ b/tdeio/tdefile/tdefilebookmarkhandler.cpp
@@ -32,7 +32,7 @@ KFileBookmarkHandler::KFileBookmarkHandler( KFileDialog *dialog )
KBookmarkOwner(),
m_dialog( dialog )
{
- m_menu = new KPopupMenu( dialog, "bookmark menu" );
+ m_menu = new TDEPopupMenu( dialog, "bookmark menu" );
TQString file = locate( "data", "tdefile/bookmarks.xml" );
if ( file.isEmpty() )
diff --git a/tdeio/tdefile/tdefilebookmarkhandler.h b/tdeio/tdefile/tdefilebookmarkhandler.h
index 6535bf961..e13e0673b 100644
--- a/tdeio/tdefile/tdefilebookmarkhandler.h
+++ b/tdeio/tdefile/tdefilebookmarkhandler.h
@@ -23,7 +23,7 @@
#include <kbookmarkmenu.h>
class TQTextStream;
-class KPopupMenu;
+class TDEPopupMenu;
class TDEIO_EXPORT KFileBookmarkHandler : public TQObject, public KBookmarkOwner
@@ -40,7 +40,7 @@ public:
virtual void openBookmarkURL( const TQString& url ) { emit openURL( url ); }
virtual TQString currentURL() const;
- KPopupMenu *menu() const { return m_menu; }
+ TDEPopupMenu *menu() const { return m_menu; }
signals:
void openURL( const TQString& url );
@@ -49,7 +49,7 @@ private:
void importOldBookmarks( const TQString& path, KBookmarkManager *manager );
KFileDialog *m_dialog;
- KPopupMenu *m_menu;
+ TDEPopupMenu *m_menu;
KBookmarkMenu *m_bookmarkMenu;
protected:
diff --git a/tdeio/tdefile/tdefiledetailview.cpp b/tdeio/tdefile/tdefiledetailview.cpp
index b989104e8..68691bf6b 100644
--- a/tdeio/tdefile/tdefiledetailview.cpp
+++ b/tdeio/tdefile/tdefiledetailview.cpp
@@ -56,7 +56,7 @@ public:
};
KFileDetailView::KFileDetailView(TQWidget *parent, const char *name)
- : KListView(parent, name), KFileView(), d(new KFileDetailViewPrivate())
+ : TDEListView(parent, name), KFileView(), d(new KFileDetailViewPrivate())
{
// this is always the static section, not the index depending on column order
m_sortingCol = COL_NAME;
@@ -149,7 +149,7 @@ void KFileDetailView::setSelected( const KFileItem *info, bool enable )
KFileListViewItem *item = (KFileListViewItem*)info->extraData( this );
if ( item )
- KListView::setSelected( item, enable );
+ TDEListView::setSelected( item, enable );
}
void KFileDetailView::setCurrentItem( const KFileItem *item )
@@ -158,7 +158,7 @@ void KFileDetailView::setCurrentItem( const KFileItem *item )
return;
KFileListViewItem *it = (KFileListViewItem*) item->extraData( this );
if ( it )
- KListView::setCurrentItem( it );
+ TDEListView::setCurrentItem( it );
}
KFileItem * KFileDetailView::currentFileItem() const
@@ -172,7 +172,7 @@ KFileItem * KFileDetailView::currentFileItem() const
void KFileDetailView::clearSelection()
{
- KListView::clearSelection();
+ TDEListView::clearSelection();
}
void KFileDetailView::selectAll()
@@ -181,12 +181,12 @@ void KFileDetailView::selectAll()
KFileView::selectionMode() == KFile::Single)
return;
- KListView::selectAll( true );
+ TDEListView::selectAll( true );
}
void KFileDetailView::invertSelection()
{
- KListView::invertSelection();
+ TDEListView::invertSelection();
}
void KFileDetailView::slotActivateMenu (TQListViewItem *item,const TQPoint& pos )
@@ -202,7 +202,7 @@ void KFileDetailView::slotActivateMenu (TQListViewItem *item,const TQPoint& pos
void KFileDetailView::clearView()
{
m_resolver->m_lstPendingMimeIconItems.clear();
- KListView::clear();
+ TDEListView::clear();
}
void KFileDetailView::insertItem( KFileItem *i )
@@ -415,8 +415,8 @@ void KFileDetailView::slotSortingChanged( int col )
}
}
- KListView::setSorting( m_sortingCol, !reversed );
- KListView::sort();
+ TDEListView::setSorting( m_sortingCol, !reversed );
+ TDEListView::sort();
if ( !m_blockSortingSignal )
sig->changeSorting( static_cast<TQDir::SortSpec>( sortSpec ) );
@@ -459,7 +459,7 @@ void KFileDetailView::ensureItemVisible( const KFileItem *i )
KFileListViewItem *item = (KFileListViewItem*) i->extraData( this );
if ( item )
- KListView::ensureItemVisible( item );
+ TDEListView::ensureItemVisible( item );
}
// we're in multiselection mode
@@ -504,7 +504,7 @@ KFileItem * KFileDetailView::prevItem( const KFileItem *fileItem ) const
void KFileDetailView::keyPressEvent( TQKeyEvent *e )
{
- KListView::keyPressEvent( e );
+ TDEListView::keyPressEvent( e );
if ( e->key() == Key_Return || e->key() == Key_Enter ) {
if ( e->state() & ControlButton )
@@ -680,7 +680,7 @@ void KFileListViewItem::init()
void KFileDetailView::virtual_hook( int id, void* data )
-{ KListView::virtual_hook( id, data );
+{ TDEListView::virtual_hook( id, data );
KFileView::virtual_hook( id, data ); }
#include "tdefiledetailview.moc"
diff --git a/tdeio/tdefile/tdefiledetailview.h b/tdeio/tdefile/tdefiledetailview.h
index 0f17b3ca9..1e2d19a6b 100644
--- a/tdeio/tdefile/tdefiledetailview.h
+++ b/tdeio/tdefile/tdefiledetailview.h
@@ -34,12 +34,12 @@ class TQKeyEvent;
* An item for the listiew, that has a reference to its corresponding
* KFileItem.
*/
-class TDEIO_EXPORT KFileListViewItem : public KListViewItem
+class TDEIO_EXPORT KFileListViewItem : public TDEListViewItem
{
public:
KFileListViewItem( TQListView *parent, const TQString &text,
const TQPixmap &icon, KFileItem *fi )
- : KListViewItem( parent, text ), inf( fi ) {
+ : TDEListViewItem( parent, text ), inf( fi ) {
setPixmap( 0, icon );
setText( 0, text );
}
@@ -48,14 +48,14 @@ public:
* @since 3.1
*/
KFileListViewItem( TQListView *parent, KFileItem *fi )
- : KListViewItem( parent ), inf( fi ) {
+ : TDEListViewItem( parent ), inf( fi ) {
init();
}
KFileListViewItem( TQListView *parent, const TQString &text,
const TQPixmap &icon, KFileItem *fi,
TQListViewItem *after)
- : KListViewItem( parent, after ), inf( fi ) {
+ : TDEListViewItem( parent, after ), inf( fi ) {
setPixmap( 0, icon );
setText( 0, text );
}
@@ -106,7 +106,7 @@ private:
* @see KCombiView
* @see KFileIconView
*/
-class TDEIO_EXPORT KFileDetailView : public KListView, public KFileView
+class TDEIO_EXPORT KFileDetailView : public TDEListView, public KFileView
{
Q_OBJECT
@@ -193,9 +193,9 @@ private slots:
void slotAutoOpen();
private:
- virtual void insertItem(TQListViewItem *i) { KListView::insertItem(i); }
- virtual void setSorting(int i, bool b) { KListView::setSorting(i, b); }
- virtual void setSelected(TQListViewItem *i, bool b) { KListView::setSelected(i, b); }
+ virtual void insertItem(TQListViewItem *i) { TDEListView::insertItem(i); }
+ virtual void setSorting(int i, bool b) { TDEListView::setSorting(i, b); }
+ virtual void setSelected(TQListViewItem *i, bool b) { TDEListView::setSelected(i, b); }
inline KFileListViewItem * viewItem( const KFileItem *item ) const {
if ( item )
diff --git a/tdeio/tdefile/tdefiledialog.h b/tdeio/tdefile/tdefiledialog.h
index ae591b21a..b7310b599 100644
--- a/tdeio/tdefile/tdefiledialog.h
+++ b/tdeio/tdefile/tdefiledialog.h
@@ -40,7 +40,7 @@ class TQLabel;
class TQPopupMenu;
class TQVBoxLayout;
-class KActionCollection;
+class TDEActionCollection;
class KDirOperator;
class KURLBar;
class KURLComboBox;
@@ -48,7 +48,7 @@ class KFileFilterCombo;
class KFileView;
class KFileItem;
class KPushButton;
-class KToolBar;
+class TDEToolBar;
class KPreviewWidgetBase;
struct KFileDialogPrivate;
@@ -713,13 +713,13 @@ public:
* You can use this to insert custom
* items into it, e.g.:
* \code
- * yourAction = new KAction( i18n("Your Action"), 0,
+ * yourAction = new TDEAction( i18n("Your Action"), 0,
* this, TQT_SLOT( yourSlot() ),
* this, "action name" );
* yourAction->plug( tdefileDialog->toolBar() );
* \endcode
*/
- KToolBar *toolBar() const { return toolbar; }
+ TDEToolBar *toolBar() const { return toolbar; }
/**
* @returns a pointer to the OK-Button in the filedialog. You may use it
@@ -752,9 +752,9 @@ public:
/**
* @returns a pointer to the action collection, holding all the used
- * KActions.
+ * TDEActions.
*/
- KActionCollection *actionCollection() const;
+ TDEActionCollection *actionCollection() const;
/**
* @returns the index of the path combobox so when inserting widgets into
@@ -769,7 +769,7 @@ public:
* @param startDir A url/directory, to be used. May use the ':' and '::' syntax
* as documented in the KFileDialog() constructor.
* @param recentDirClass If the ':' or '::' syntax is used, recentDirClass
- * will contain the string to be used later for KRecentDir::dir()
+ * will contain the string to be used later for TDERecentDir::dir()
* @return The URL that should be listed by default (e.g. by KFileDialog or
* KDirSelectDialog).
* @since 3.1
@@ -820,7 +820,7 @@ signals:
void filterChanged( const TQString& filter );
protected:
- KToolBar *toolbar;
+ TDEToolBar *toolbar;
static KURL *lastDirectory;
diff --git a/tdeio/tdefile/tdefileiconview.cpp b/tdeio/tdefile/tdefileiconview.cpp
index 474364042..d42373893 100644
--- a/tdeio/tdefile/tdefileiconview.cpp
+++ b/tdeio/tdefile/tdefileiconview.cpp
@@ -60,12 +60,12 @@ public:
noArrangement = false;
ignoreMaximumSize = false;
- smallColumns = new KRadioAction( i18n("Small Icons"), 0, TQT_TQOBJECT(parent),
+ smallColumns = new TDERadioAction( i18n("Small Icons"), 0, TQT_TQOBJECT(parent),
TQT_SLOT( slotSmallColumns() ),
parent->actionCollection(),
"small columns" );
- largeRows = new KRadioAction( i18n("Large Icons"), 0, TQT_TQOBJECT(parent),
+ largeRows = new TDERadioAction( i18n("Large Icons"), 0, TQT_TQOBJECT(parent),
TQT_SLOT( slotLargeRows() ),
parent->actionCollection(),
"large rows" );
@@ -73,7 +73,7 @@ public:
smallColumns->setExclusiveGroup(TQString::fromLatin1("IconView mode"));
largeRows->setExclusiveGroup(TQString::fromLatin1("IconView mode"));
- previews = new KToggleAction( i18n("Thumbnail Previews"), 0,
+ previews = new TDEToggleAction( i18n("Thumbnail Previews"), 0,
parent->actionCollection(),
"show previews" );
zoomIn = KStdAction::zoomIn( TQT_TQOBJECT(parent), TQT_SLOT( zoomIn() ),
@@ -99,9 +99,9 @@ public:
job->kill();
}
- KRadioAction *smallColumns, *largeRows;
- KAction *zoomIn, *zoomOut;
- KToggleAction *previews;
+ TDERadioAction *smallColumns, *largeRows;
+ TDEAction *zoomIn, *zoomOut;
+ TDEToggleAction *previews;
TDEIO::PreviewJob *job;
KFileIconViewItem *dropItem;
TQTimer previewTimer;
diff --git a/tdeio/tdefile/tdefilepreview.cpp b/tdeio/tdefile/tdefilepreview.cpp
index 4e9365361..4b336afee 100644
--- a/tdeio/tdefile/tdefilepreview.cpp
+++ b/tdeio/tdefile/tdefilepreview.cpp
@@ -254,7 +254,7 @@ KFileItem * KFilePreview::prevItem( const KFileItem *item ) const
return left->prevItem( item );
}
-KActionCollection * KFilePreview::actionCollection() const
+TDEActionCollection * KFilePreview::actionCollection() const
{
if ( left )
return left->actionCollection();
diff --git a/tdeio/tdefile/tdefiletreeview.h b/tdeio/tdefile/tdefiletreeview.h
index 11d695288..3d6e039f5 100644
--- a/tdeio/tdefile/tdefiletreeview.h
+++ b/tdeio/tdefile/tdefiletreeview.h
@@ -63,7 +63,7 @@ private:
* 3. retrieve the root item with KFileTreeBranch::root() and set it open
* if desired. That starts the listing.
*/
-class TDEIO_EXPORT KFileTreeView : public KListView
+class TDEIO_EXPORT KFileTreeView : public TDEListView
{
Q_OBJECT
public:
diff --git a/tdeio/tdefile/tdefiletreeviewitem.cpp b/tdeio/tdefile/tdefiletreeviewitem.cpp
index 4df2daaa1..3f7e5a485 100644
--- a/tdeio/tdefile/tdefiletreeviewitem.cpp
+++ b/tdeio/tdefile/tdefiletreeviewitem.cpp
@@ -29,7 +29,7 @@
KFileTreeViewItem::KFileTreeViewItem( KFileTreeViewItem *parent,
KFileItem* item,
KFileTreeBranch *brnch )
- : KListViewItem( parent ),
+ : TDEListViewItem( parent ),
m_tdefileitem( item ),
m_branch( brnch ),
m_wasListed(false)
@@ -42,7 +42,7 @@ KFileTreeViewItem::KFileTreeViewItem( KFileTreeViewItem *parent,
KFileTreeViewItem::KFileTreeViewItem( KFileTreeView* parent,
KFileItem* item,
KFileTreeBranch *brnch )
- :KListViewItem( (TQListView*)parent ),
+ :TDEListViewItem( (TQListView*)parent ),
m_tdefileitem(item ),
m_branch( brnch ),
m_wasListed(false)
diff --git a/tdeio/tdefile/tdefiletreeviewitem.h b/tdeio/tdefile/tdefiletreeviewitem.h
index 8fdb2789c..4455bff78 100644
--- a/tdeio/tdefile/tdefiletreeviewitem.h
+++ b/tdeio/tdefile/tdefiletreeviewitem.h
@@ -37,7 +37,7 @@ class KFileTreeItem;
/**
* An item for a KFileTreeView that knows about its own KFileItem.
*/
-class TDEIO_EXPORT KFileTreeViewItem : public KListViewItem
+class TDEIO_EXPORT KFileTreeViewItem : public TDEListViewItem
{
public:
KFileTreeViewItem( KFileTreeViewItem*, KFileItem*, KFileTreeBranch * );
diff --git a/tdeio/tdefile/tdefileview.cpp b/tdeio/tdefile/tdefileview.cpp
index 558053cc8..01bc5e6b0 100644
--- a/tdeio/tdefile/tdefileview.cpp
+++ b/tdeio/tdefile/tdefileview.cpp
@@ -55,7 +55,7 @@ public:
}
}
- TQGuardedPtr<KActionCollection> actions;
+ TQGuardedPtr<TDEActionCollection> actions;
int dropOptions;
};
@@ -362,10 +362,10 @@ void KFileView::listingCompleted()
// empty default impl.
}
-KActionCollection * KFileView::actionCollection() const
+TDEActionCollection * KFileView::actionCollection() const
{
if ( !d->actions )
- d->actions = new KActionCollection( widget(), "KFileView::d->actions" );
+ d->actions = new TDEActionCollection( widget(), "KFileView::d->actions" );
return d->actions;
}
diff --git a/tdeio/tdefile/tdefileview.h b/tdeio/tdefile/tdefileview.h
index 79aa1b478..b80c16f0f 100644
--- a/tdeio/tdefile/tdefileview.h
+++ b/tdeio/tdefile/tdefileview.h
@@ -23,7 +23,7 @@
#define TDEFILEVIEW_H
class TQPoint;
-class KActionCollection;
+class TDEActionCollection;
#include <tqwidget.h>
@@ -342,7 +342,7 @@ public:
* add its actions here (if it has any) to make them available to
* e.g. the KDirOperator's popup-menu.
*/
- virtual KActionCollection * actionCollection() const;
+ virtual TDEActionCollection * actionCollection() const;
KFileViewSignaler * signaler() const { return sig; }
diff --git a/tdeio/tdefile/tests/tdefiletreeviewtest.cpp b/tdeio/tdefile/tests/tdefiletreeviewtest.cpp
index b74468fda..008edb827 100644
--- a/tdeio/tdefile/tests/tdefiletreeviewtest.cpp
+++ b/tdeio/tdefile/tests/tdefiletreeviewtest.cpp
@@ -33,7 +33,7 @@
#include "tdefiletreeviewtest.moc"
-testFrame::testFrame():KMainWindow(0,"Test FileTreeView"),
+testFrame::testFrame():TDEMainWindow(0,"Test FileTreeView"),
dirOnlyMode(false)
{
diff --git a/tdeio/tdefile/tests/tdefiletreeviewtest.h b/tdeio/tdefile/tests/tdefiletreeviewtest.h
index 05f41fcfb..0375f8d11 100644
--- a/tdeio/tdefile/tests/tdefiletreeviewtest.h
+++ b/tdeio/tdefile/tests/tdefiletreeviewtest.h
@@ -20,7 +20,7 @@
#ifndef TDEFILETREEVIEWTEST
#define TDEFILETREEVIEWTEST
-class testFrame: public KMainWindow
+class testFrame: public TDEMainWindow
{
Q_OBJECT
public:
diff --git a/tdeio/tdefile/kdiroperator.h b/tdeio/tdefile/kdiroperator.h
index 418bb20c8..5d806eee2 100644
--- a/tdeio/tdefile/kdiroperator.h
+++ b/tdeio/tdefile/kdiroperator.h
@@ -34,11 +34,11 @@
class TQPopupMenu;
class TQTimer;
-class KAction;
+class TDEAction;
class KDirLister;
-class KToggleAction;
-class KActionSeparator;
-class KActionMenu;
+class TDEToggleAction;
+class TDEActionSeparator;
+class TDEActionMenu;
class TQWidgetStack;
class KProgress;
namespace TDEIO {
@@ -345,7 +345,7 @@ class TDEIO_EXPORT KDirOperator : public TQWidget
/**
* an accessor to a collection of all available Actions. The actions
* are static, they will be there all the time (no need to connect to
* the signals KActionCollection::inserted() or removed().
*
* There are the following actions:
*
@@ -387,7 +387,7 @@ class TDEIO_EXPORT KDirOperator : public TQWidget
*
* @returns all available Actions
*/
- KActionCollection * actionCollection() const { return myActionCollection; }
+ TDEActionCollection * actionCollection() const { return myActionCollection; }
/**
* Sets the config object and the to be used group in KDirOperator. This
@@ -710,7 +710,7 @@ public slots:
* @since 3.4
*/
// ### KDE4: make virtual
- void trashSelected(KAction::ActivationReason, TQt::ButtonState);
+ void trashSelected(TDEAction::ActivationReason, TQt::ButtonState);
protected slots:
/**
@@ -873,32 +873,32 @@ private:
// actions for the popupmenus
// ### clean up all those -- we have them all in the actionMenu!
- KActionMenu *actionMenu;
-
- KAction *backAction;
- KAction *forwardAction;
- KAction *homeAction;
- KAction *upAction;
- KAction *reloadAction;
- KActionSeparator *actionSeparator;
- KAction *mkdirAction;
-
- KActionMenu *sortActionMenu;
- KRadioAction *byNameAction;
- KRadioAction *byDateAction;
- KRadioAction *bySizeAction;
- KToggleAction *reverseAction;
- KToggleAction *dirsFirstAction;
- KToggleAction *caseInsensitiveAction;
-
- KActionMenu *viewActionMenu;
- KRadioAction *shortAction;
- KRadioAction *detailedAction;
- KToggleAction *showHiddenAction;
- KToggleAction *separateDirsAction;
-
- KActionCollection *myActionCollection;
- KActionCollection *viewActionCollection;
+ TDEActionMenu *actionMenu;
+
+ TDEAction *backAction;
+ TDEAction *forwardAction;
+ TDEAction *homeAction;
+ TDEAction *upAction;
+ TDEAction *reloadAction;
+ TDEActionSeparator *actionSeparator;
+ TDEAction *mkdirAction;
+
+ TDEActionMenu *sortActionMenu;
+ TDERadioAction *byNameAction;
+ TDERadioAction *byDateAction;
+ TDERadioAction *bySizeAction;
+ TDEToggleAction *reverseAction;
+ TDEToggleAction *dirsFirstAction;
+ TDEToggleAction *caseInsensitiveAction;
+
+ TDEActionMenu *viewActionMenu;
+ TDERadioAction *shortAction;
+ TDERadioAction *detailedAction;
+ TDEToggleAction *showHiddenAction;
+ TDEToggleAction *separateDirsAction;
+
+ TDEActionCollection *myActionCollection;
+ TDEActionCollection *viewActionCollection;
private slots:
/**
@@ -926,8 +926,8 @@ private slots:
void slotCanceled();
void slotRedirected( const KURL& );
- void slotViewActionAdded( KAction * );
- void slotViewActionRemoved( KAction * );
+ void slotViewActionAdded( TDEAction * );
+ void slotViewActionRemoved( TDEAction * );
void slotViewSortingChanged( TQDir::SortSpec );
void slotClearView();
@@ -345,7 +345,7 @@ class TDEIO_EXPORT KDirOperator : public TQWidget
* an accessor to a collection of all available Actions. The actions
* are static, they will be there all the time (no need to connect to
- * the signals KActionCollection::inserted() or removed().
+ * the signals TDEActionCollection::inserted() or removed().
*
* There are the following actions:
diff --git a/tdeio/tdefile/kurlbar.h b/tdeio/tdefile/kurlbar.h
index 32c05ec58..7470ec82a 100644
--- a/tdeio/tdefile/kurlbar.h
+++ b/tdeio/tdefile/kurlbar.h
@@ -483,14 +483,14 @@ class TQDragObject;
class KURLBarToolTip;
/**
* This is the listbox used in KURLBar. It is a subclass of KListBox to support
* drag & drop and to set up the row / column mode.
*
* The widget has just one row or one column, depending on orientation().
*
* @author Carsten Pfeiffer <pfeiffer@kde.org>
*/
-class TDEIO_EXPORT KURLBarListBox : public KListBox
+class TDEIO_EXPORT KURLBarListBox : public TDEListBox
{
Q_OBJECT
@@ -483,14 +483,14 @@ class TQDragObject;
class KURLBarToolTip;
/**
- * This is the listbox used in KURLBar. It is a subclass of KListBox to support
+ * This is the listbox used in KURLBar. It is a subclass of TDEListBox to support
* drag & drop and to set up the row / column mode.
*
diff --git a/tdeio/tdefile/tdefiledialog.cpp b/tdeio/tdefile/tdefiledialog.cpp
index 4fb399716..f60692c88 100644
--- a/tdeio/tdefile/tdefiledialog.cpp
+++ b/tdeio/tdefile/tdefiledialog.cpp
@@ -153,7 +153,7 @@ struct KFileDialogPrivate
bool hasDefaultFilter :1; // necessary for the operationMode
KFileDialog::OperationMode operationMode;
// The file class used for KRecentDirs
TQString fileClass;
KFileBookmarkHandler *bookmarkHandler;
@@ -648,7 +648,7 @@ void KFileDialog::accept()
*lastDirectory = ops->url();
if (!d->fileClass.isEmpty())
- KRecentDirs::add(d->fileClass, ops->url().url());
+ TDERecentDirs::add(d->fileClass, ops->url().url());
// clear the topmost item, we insert it as full path later on as item 1
locationEdit->changeItem( TQString::null, 0 );
@@ -832,7 +832,7 @@ void KFileDialog::init(const TQString& startDir, const TQString& filter, TQWidge
d->urlBar = 0; // delayed loading
TQtMsgHandler oldHandler = tqInstallMsgHandler( silenceQToolBar );
- toolbar = new KToolBar( d->mainWidget, "KFileDialog::toolbar", true);
+ toolbar = new TDEToolBar( d->mainWidget, "KFileDialog::toolbar", true);
toolbar->setFlat(true);
tqInstallMsgHandler( oldHandler );
@@ -905,7 +905,7 @@ void KFileDialog::init(const TQString& startDir, const TQString& filter, TQWidge
ops->setupMenu(KDirOperator::SortActions |
KDirOperator::FileActions |
KDirOperator::ViewActions);
- KActionCollection *coll = ops->actionCollection();
+ TDEActionCollection *coll = ops->actionCollection();
// plug nav items into the toolbar
coll->action( "up" )->plug( toolbar );
@@ -922,19 +922,19 @@ void KFileDialog::init(const TQString& startDir, const TQString& filter, TQWidge
coll->action( "mkdir" )->plug( toolbar );
coll->action( "mkdir" )->setWhatsThis(i18n("Click this button to create a new folder."));
- KToggleAction *showSidebarAction =
- new KToggleAction(i18n("Show Quick Access Navigation Panel"), Key_F9, coll,"toggleSpeedbar");
+ TDEToggleAction *showSidebarAction =
+ new TDEToggleAction(i18n("Show Quick Access Navigation Panel"), Key_F9, coll,"toggleSpeedbar");
showSidebarAction->setCheckedState(i18n("Hide Quick Access Navigation Panel"));
connect( showSidebarAction, TQT_SIGNAL( toggled( bool ) ),
TQT_SLOT( toggleSpeedbar( bool )) );
- KToggleAction *showBookmarksAction =
- new KToggleAction(i18n("Show Bookmarks"), 0, coll, "toggleBookmarks");
+ TDEToggleAction *showBookmarksAction =
+ new TDEToggleAction(i18n("Show Bookmarks"), 0, coll, "toggleBookmarks");
showBookmarksAction->setCheckedState(i18n("Hide Bookmarks"));
connect( showBookmarksAction, TQT_SIGNAL( toggled( bool ) ),
TQT_SLOT( toggleBookmarks( bool )) );
- KActionMenu *menu = new KActionMenu( i18n("Configure"), "configure", TQT_TQOBJECT(this), "extra menu" );
+ TDEActionMenu *menu = new TDEActionMenu( i18n("Configure"), "configure", TQT_TQOBJECT(this), "extra menu" );
menu->setWhatsThis(i18n("<qt>This is the configuration menu for the file dialog. "
"Various options can be accessed from this menu including: <ul>"
"<li>how files are sorted in the list</li>"
@@ -965,15 +965,15 @@ void KFileDialog::init(const TQString& startDir, const TQString& filter, TQWidge
menu->plug( toolbar );
//Insert a separator.
- KToolBarSeparator* spacerWidget = new KToolBarSeparator(Qt::Horizontal, false /*no line*/,
+ TDEToolBarSeparator* spacerWidget = new TDEToolBarSeparator(Qt::Horizontal, false /*no line*/,
toolbar);
d->m_pathComboIndex = toolbar->insertWidget(-1, -1, spacerWidget);
toolbar->insertWidget(PATH_COMBO, 0, d->pathCombo);
toolbar->setItemAutoSized (PATH_COMBO);
- toolbar->setIconText(KToolBar::IconOnly);
- toolbar->setBarPos(KToolBar::Top);
+ toolbar->setIconText(TDEToolBar::IconOnly);
+ toolbar->setBarPos(TDEToolBar::Top);
toolbar->setMovingEnabled(false);
toolbar->adjustSize();
@@ -1609,7 +1609,7 @@ TQString KFileDialog::getSaveFileName(const TQString& dir, const TQString& filte
TQString filename = dlg.selectedFile();
if (!filename.isEmpty())
- KRecentDocument::add(filename);
+ TDERecentDocument::add(filename);
return filename;
}
@@ -1638,7 +1638,7 @@ TQString KFileDialog::getSaveFileNameWId(const TQString& dir, const TQString& fi
TQString filename = dlg.selectedFile();
if (!filename.isEmpty())
- KRecentDocument::add(filename);
+ TDERecentDocument::add(filename);
return filename;
}
@@ -1658,7 +1658,7 @@ KURL KFileDialog::getSaveURL(const TQString& dir, const TQString& filter,
KURL url = dlg.selectedURL();
if (url.isValid())
- KRecentDocument::add( url );
+ TDERecentDocument::add( url );
return url;
}
@@ -2189,7 +2189,7 @@ void KFileDialog::addToRecentDocuments()
TQStringList files = selectedFiles();
TQStringList::ConstIterator it = files.begin();
for ( ; it != files.end(); ++it )
- KRecentDocument::add( *it );
+ TDERecentDocument::add( *it );
}
else { // urls
@@ -2197,12 +2197,12 @@ void KFileDialog::addToRecentDocuments()
KURL::List::ConstIterator it = urls.begin();
for ( ; it != urls.end(); ++it ) {
if ( (*it).isValid() )
- KRecentDocument::add( *it );
+ TDERecentDocument::add( *it );
}
}
}
-KActionCollection * KFileDialog::actionCollection() const
+TDEActionCollection * KFileDialog::actionCollection() const
{
return ops->actionCollection();
}
@@ -2251,7 +2251,7 @@ void KFileDialog::toggleSpeedbar( bool show )
ops->actionCollection()->action( "home" )->plug( toolbar, 3 );
}
- static_cast<KToggleAction *>(actionCollection()->action("toggleSpeedbar"))->setChecked( show );
+ static_cast<TDEToggleAction *>(actionCollection()->action("toggleSpeedbar"))->setChecked( show );
}
void KFileDialog::toggleBookmarks(bool show)
@@ -2286,7 +2286,7 @@ void KFileDialog::toggleBookmarks(bool show)
toolbar->removeItem(HOTLIST_BUTTON);
}
- static_cast<KToggleAction *>(actionCollection()->action("toggleBookmarks"))->setChecked( show );
+ static_cast<TDEToggleAction *>(actionCollection()->action("toggleBookmarks"))->setChecked( show );
}
int KFileDialog::pathComboIndex()
@@ -2318,7 +2318,7 @@ KURL KFileDialog::getStartURL( const TQString& startDir,
if (startDir[0] == ':')
{
recentDirClass = startDir;
- ret = KURL::fromPathOrURL( KRecentDirs::dir(recentDirClass) );
+ ret = KURL::fromPathOrURL( TDERecentDirs::dir(recentDirClass) );
}
else
{
@@ -153,7 +153,7 @@ struct KFileDialogPrivate
bool hasDefaultFilter :1; // necessary for the operationMode
KFileDialog::OperationMode operationMode;
- // The file class used for KRecentDirs
+ // The file class used for TDERecentDirs
TQString fileClass;
KFileBookmarkHandler *bookmarkHandler;
diff --git a/tdeio/tdefile/tdefilepreview.h b/tdeio/tdefile/tdefilepreview.h
index 5bc59dba5..16cfa281b 100644
--- a/tdeio/tdefile/tdefilepreview.h
+++ b/tdeio/tdefile/tdefilepreview.h
@@ -89,10 +89,10 @@ public:
/**
* This overrides KFileView::actionCollection() by returning
* the actionCollection() of the KFileView (member left) it contains.
* This means that KFilePreview will never create a KActionCollection
* object of its own.
*/
- virtual KActionCollection * actionCollection() const;
+ virtual TDEActionCollection * actionCollection() const;
void ensureItemVisible(const KFileItem *);
@@ -89,10 +89,10 @@ public:
* This overrides KFileView::actionCollection() by returning
* the actionCollection() of the KFileView (member left) it contains.
- * This means that KFilePreview will never create a KActionCollection
+ * This means that KFilePreview will never create a TDEActionCollection
* object of its own.
*/
diff --git a/tdeio/tdefile/tdefiletreeview.cpp b/tdeio/tdefile/tdefiletreeview.cpp
index 480c58ec3..fd7d630e1 100644
--- a/tdeio/tdefile/tdefiletreeview.cpp
+++ b/tdeio/tdefile/tdefiletreeview.cpp
@@ -40,12 +40,12 @@
#include "tdefiletreeviewitem.h"
KFileTreeView::KFileTreeView( TQWidget *parent, const char *name )
- : KListView( parent, name ),
+ : TDEListView( parent, name ),
m_wantOpenFolderPixmaps( true ),
m_toolTip( this )
{
setDragEnabled(true);
- setSelectionModeExt( KListView::Single );
+ setSelectionModeExt( TDEListView::Single );
m_animationTimer = new TQTimer( this );
connect( m_animationTimer, TQT_SIGNAL( timeout() ),
@@ -235,8 +235,8 @@ bool KFileTreeView::acceptDrag(TQDropEvent* e ) const
// kdDebug(250) << "canDecode: " << KURLDrag::canDecode(e) << endl;
// kdDebug(250) << "action: " << e->action() << endl;
/* KListView::acceptDrag(e); */
/* this is what KListView does:
* acceptDrops() && itemsMovable() && (e->source()==viewport());
* ask acceptDrops and itemsMovable, but not the third
*/
@@ -672,6 +672,6 @@ void KFileTreeViewToolTip::maybeTip( const TQPoint & )
}
void KFileTreeView::virtual_hook( int id, void* data )
-{ KListView::virtual_hook( id, data ); }
+{ TDEListView::virtual_hook( id, data ); }
#include "tdefiletreeview.moc"
@@ -235,8 +235,8 @@ bool KFileTreeView::acceptDrag(TQDropEvent* e ) const
// kdDebug(250) << "canDecode: " << KURLDrag::canDecode(e) << endl;
// kdDebug(250) << "action: " << e->action() << endl;
- /* KListView::acceptDrag(e); */
- /* this is what KListView does:
+ /* TDEListView::acceptDrag(e); */
+ /* this is what TDEListView does:
* acceptDrops() && itemsMovable() && (e->source()==viewport());
* ask acceptDrops and itemsMovable, but not the third